# opat

[![codecov](https://codecov.io/gh/shawnlinxl/opat/branch/master/graph/badge.svg)](https://codecov.io/gh/shawnlinxl/opat)
[![build status](https://travis-ci.org/shawnlinxl/opat.svg?branch=master)](https://travis-ci.org/shawnlinxl/opat)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

opat stands for Open Portfolio Analysis Tool, It is a Python library for 
performance and risk analysis of financial portfolios developed by Shawn Lin

## Installation

To install opat, run:

```bash
pip install opat
```

## Features

### Statistics
Provide basic portfolio performance and risk statistics

### Portfolio
Common portfolio aggregation tools.